@@ -6,7 +6,7 @@ from . import mail_shell as mshell
 def main():
 	ARGS = sys.argv
 	if '--version' in ARGS:
-		helper.get_vertion()
+		helper.get_version()
 	elif '--help' in ARGS or '-h' in ARGS:
 		helper.shell_commands()
 	else:
