@@ -24,8 +24,8 @@ SEND_TO_STR = r"//↓↓↓↓ Send to ↓↓↓↓\\"
 
 def update_warning():
 	response = requests.get("https://pypi.org/pypi/mailshell/json")
-	current_vertion = response.json()['info']['version']
-	if helper.VERSION == current_vertion:
+	current_version = response.json()['info']['version']
+	if helper.VERSION == current_version:
 		return ''
 	warning = f"\n\x1b[33mWARNING: new version available [{current_version}]\n"
 	warning += "run 'pip3 install -U mailshell' to update.\x1b[0m"
@@ -51,6 +51,14 @@ def folder_ls(folder='.'):
 def print_work_directory():
 	print(os.getcwd())
 
+def less(text=''):
+	with NamedTemporaryFile(mode='w') as tmp:
+		tmp.write(text + "\nPress 'q' to END")
+		tmp.flush()
+		os.fsync(tmp.fileno())
+		call(['less', '-X', tmp.name])
+	
+
 clear = lambda: os.system('clear')
 
 class User(object):
@@ -62,6 +70,7 @@ class Mailshell():
 	def __init__(self):
 		self.user = None
 		self.message = None
+		self.html_message = ""
 		self.contacts = {}
 		self.commands = {
 			"logo": dispaly_logo,
@@ -70,9 +79,12 @@ class Mailshell():
 			"cred": self.credentials,
 			"new": self.new_message,
 			"edit": self.edit_message,
+			"html": self.add_html,
 			"content": self.show_content,
 			"send": self.send_message,
 			"to": self.message_to,
+			"subject": self.set_subject,
+			"from": self.set_from,
 			"get": self.get_text,
 			"add": self.add_file,
 			"rm": self.remove_file,
@@ -104,14 +116,16 @@ class Mailshell():
 	def __error_connection(self):
 		print("\nConnection error: please check your network!\n")
 
-	def __get_multiline_input(self, prefix=''):
+	def __get_multiline_input(self, prefix='', strp=False):
 		with NamedTemporaryFile(mode='w') as f:
 			f.write(prefix)
 			f.flush()
 			os.fsync(f.fileno())
 			with open(f.name, 'r') as tmp:
 				call(['nano', tmp.name])
-				return tmp.read()
+				text = tmp.read()
+				if strp: text = text.strip()
+				return text
 
 	def log_in(self):
 		print('Log in:')
@@ -163,8 +177,8 @@ class Mailshell():
 			return
 		print("Creating new message:")
 		self.message = EmailMessage()
-		self.message['Subject'] = input('Subject: ').strip()
-		self.message['From'] = self.user.address
+		self.set_subject(True)
+		self.set_from(True)
 		self.message.set_content('')
 
 	def edit_message(self):
@@ -178,6 +192,39 @@ class Mailshell():
 			self.message.get_payload()[0].set_content(new_content)
 			return
 		self.message.set_content(new_content)
+
+	def add_html(self):
+		if not self.message:
+			self.__error_create_message()
+			return
+		content_type = type(self.message.get_payload())
+		if content_type == list:
+			for idx, part in enumerate(self.message.get_payload()):
+				if part.get_content_subtype() == "html": del self.message.get_payload()[idx]
+		self.html_message = self.__get_multiline_input(self.html_message, True)
+		if self.html_message:
+			self.message.add_alternative(self.html_message, subtype='html')
+
+	def set_subject(self, allowed=False):
+		if not allowed and not self.message:
+			self.__error_create_message()
+			return
+		while True:
+			subject = input("Subject: ").strip()
+			if subject: 
+				del self.message['Subject']
+				self.message['Subject'] = subject
+				break
+			print("You have to set a Subject to your message!")
+
+	def set_from(self, allowed=False):
+		if not self.message:
+			self.__error_create_message()
+			return
+		sender = input("From: ").strip()
+		if sender: sender += ' '
+		del self.message['From']
+		self.message['From'] = sender + f"<{self.user.address}>"
 	
 	def get_text(self, file_path=''):
 		if not self.message:
@@ -237,18 +284,20 @@ class Mailshell():
 			self.__error_create_message()
 			return
 		content = MESSAGE_STR + '\n'
-		content += "Subject: " + self.message['Subject'] + '\n'
-		content += "From: " + self.message['From'] + '\n'
-		text = self.message.get_payload()
-		if type(text) != str: text = text[0].get_content()
+		content += "Subject:\t" + self.message['Subject'] + '\n'
+		content += "From:\t" + self.message['From'] + '\n'
+		if self.html_message: text = self.html_message
+		else:
+			text = self.message.get_payload()
+			if type(text) != str: text = text[0].get_content()
 		content += text + '\n'
 		attachments = list(self.message.iter_attachments())
 		if len(attachments):
 			content += "- includes:\n"
-			for att in attachments: content += '\x1b[33m    ' + att.get_filename() + '\x1b[0m' + '\n'
+			for att in attachments: content += f"\x1b[33m\t{att.get_filename()}\x1b[0m\n"
 		content += '-' * len(MESSAGE_STR)
 		print(content)
-		print("type 'send' to send your message.")
+		print("\ntype 'send' to send your message.")
 
 	def check_mail_box(self):
 		if not self.user:
@@ -261,11 +310,7 @@ class Mailshell():
 			self.__error_connection()
 
 	def display_sc(self):
-		with NamedTemporaryFile(mode='w') as tmp:
-			tmp.write(helper.IMAP_CRITERIAS)
-			tmp.flush()
-			os.fsync(tmp.fileno())
-			call(['less', tmp.name])
+		less(helper.IMAP_CRITERIAS)
 
 	def message_to(self):
 		pre = SEND_TO_STR + '\n'
@@ -287,6 +332,7 @@ class Mailshell():
 			print("Connecting..")
 			with smtplib.SMTP_SSL(SMTP_SERVER, PORT) as smtp:
 				smtp.login(self.user.address, self.user.app_password)
+				
 				for user in self.contacts:
 					print(f"Sending to {user}..")
 					if not validate_email(user):
@@ -308,11 +354,12 @@ class Mailshell():
 			elif keys[0] in ['ls', 'get', 'add', 'rm']: self.commands[keys[0]](keys[1])
 			else: print(f"{command}: command not found.")
 
-def shell_line(user):
-	if not user: address = ""
-	else: address = f"\x1b[31m@\x1b[0m{user.address}"
-	username = "\x1b[33m" + getuser()
-	return username + address + '\x1b[31m>> \x1b[0m'
+def shell_line(shell):
+	line = "\x1b[33m" + getuser()
+	if shell.user: line += f"\x1b[31m@\x1b[0m" + shell.user.address
+	if shell.message: line += f"\x1b[31m[\x1b[0m📧{shell.message['Subject']}\x1b[31m]"
+	line += '\x1b[31m>> \x1b[0m'
+	return line
 	
 
 def run():
@@ -330,5 +377,5 @@ def run():
 			credentials = next(csv.reader(f))
 			SHELL.user = User(*credentials)
 
-	while True: SHELL[input(shell_line(SHELL.user)).strip()]
+	while True: SHELL[input(shell_line(SHELL)).strip()]
 
